// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  TU Dresden                                                            ==
// ==                                                                        ==
// ==  Institut fr Wissenschaftliches Rechnen                               ==
// ==  Zellescher Weg 12-14                                                  ==
// ==  01069 Dresden                                                         ==
// ==  germany                                                               ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  https://gforge.zih.tu-dresden.de/projects/amdis/                      ==
// ==                                                                        ==
// ============================================================================

/** \file ParallelDomainScal.h */

#ifndef AMDIS_PARALLELDOMAINSCAL_H
#define AMDIS_PARALLELDOMAINSCAL_H

#include "ParallelDomainBase.h"
#include "ProblemScal.h"

namespace AMDiS {

  class ParallelDomainScal : public ParallelDomainBase
  {
  public:
    ParallelDomainScal(ProblemScal *problem,
		       ProblemInstatScal *problemInstat);

    void initParallelization(AdaptInfo *adaptInfo);

    // Writes all data of this object to an output stream.
    virtual void serialize(std::ostream &out)
    {
      probScal->serialize(out);
      ParallelDomainBase::serialize(out);
    }

    // Reads the object data from an input stream.
    virtual void deserialize(std::istream &in)
    {
      probScal->deserialize(in);
      ParallelDomainBase::deserialize(in);
    }

  protected:
    /// Starts the solution of the linear system using Petsc.
    void solve();

  protected:
    /// Pointer to the stationary problem.
    ProblemScal *probScal;
  };

}

#endif // AMDIS_PARALLELDOMAINSCAL_H
